@@ -82,7 +82,7 @@ def list_by_path(manifest_name, path, cache):
             # optimization for stacks.
             del dirs[:]
             continue #leaf     
-        elif 'rospack_nosubdirs' in files or 'CATKIN_NO_SUBDIRS' in files:
+        elif 'rospack_nosubdirs' in files or 'CATKIN_IGNORE' in files:
             del dirs[:]
             continue  #leaf
         # remove hidden dirs (esp. .svn/.git)
